@@ -26,12 +26,22 @@ type dir =
   | Dir_record (** Record stream. *)
   | Dir_upload (** Sample upload stream. *)
 
+(** Attributes of the buffer. *)
+type buffer_attr =
+    {
+      max_length : int; (** Maximum length of the buffer. *)
+      target_length : int; (** Target length of the buffer (playback only). *)
+      prebuffering : int; (** Pre-buffering (playback only). *)
+      min_request : int; (** Minimum request (playback only). *)
+      fragment_size : int; (** Fragment size (recording only). *)
+    }
+
 (** Simple pulseaudio interface. *)
 module Simple : sig
   (** Connections to a server. *)
   type t
 
-  val create : ?server:string -> client_name:string -> dir:dir -> ?dev:string -> stream_name:string -> sample:sample -> ?map:map -> unit -> t
+  val create : ?server:string -> client_name:string -> dir:dir -> ?dev:string -> stream_name:string -> sample:sample -> ?map:map -> ?attr:buffer_attr -> unit -> t
 
   (** Close and free a connection to a server. *)
   val free : t -> unit
